@@ -17,7 +17,7 @@ def start_job(dir_path, currentfile, progressbar_batch, progressbar_singlefile,
 def ocr_run(file_path, ocrmypdfsettings):
 	#runs ocrmypdf on given file
 	try:
-		ocr = ocrmypdf.ocr(file_path, file_path, **ocrmypdfsettings, plugins=["plugin_progressbar"])
+		ocr = ocrmypdf.ocr(file_path, file_path, **ocrmypdfsettings, plugins=["ocrmypdfgui.plugin_progressbar"])
 
 		print("OCR complete.\n")
 		return "OCR complete.\n"
